"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.client_service import (
    ClientService,
)


class Visit(object):
    """Implementation of the 'Visit' model.

    Represents a specific visit to a class

    Attributes:
        appointment_id (int): The appointment’s ID.
        appointment_gender_preference (AppointmentGenderPreferenceEnum): The gender
            of staff member with whom the client prefers to book appointments.
            Possible values are:  * Female - Indicates that the client prefers to
            book appointments with female staff members.  * Male - Indicates that the
            client prefers to book appointments with male staff members.  * None -
            Indicates that the client does not have a staff member gender preference.
        appointment_status (AppointmentStatusEnum): The status of the appointment.
        class_id (int): The class ID that was used to retrieve the visits.
        client_id (str): The ID of the client associated with the visit.
        client_photo_url (str): PhotoUrl for the client
        client_unique_id (int): The unique ID of the client associated with the visit.
        start_date_time (datetime): The time this class is scheduled to start.
        end_date_time (datetime): The date and time the visit ends. The Public API
            returns UTC dates and times. For example, a class that occurs on June
            25th, 2018 at 2:15PM (EST) appears as “2018-06-25T19:15:00Z” because EST
            is five hours behind UTC. Date time pairs always return in the format
            YYYY-MM-DDTHH:mm:ssZ.
        id (int): The ID of the visit.
        last_modified_date_time (datetime): When included in the request, only
            records modified on or after the specified `LastModifiedDate` are
            included in the response. The Public API returns UTC dates and times. For
            example, a class that occurs on June 25th, 2018 at 2:15PM (EST) appears
            as “2018-06-25T19:15:00Z” because EST is five hours behind UTC. Date time
            pairs always return in the format YYYY-MM-DDTHH:mm:ssZ.
        late_cancelled (bool): When `true`, indicates that the class has been
            `LateCancelled`.<br />  When `false`, indicates that the class has not
            been `LateCancelled`.
        site_id (int): The ID of the business where the visit is booked.
        location_id (int): The ID of the location where the visit took place or is to
            take place.
        make_up (bool): When `true`, the client can make up this session and a
            session is not deducted from the pricing option that was used to sign the
            client into the enrollment. When the client has the make-up session, a
            session is automatically removed from a pricing option that matches the
            service category of the enrollment and is within the same date range of
            the missed session.<br />  When `false`, the client cannot make up this
            session. See [Enrollments:
            Make-ups](https://support.mindbodyonline.com/s/article/203259433-Enrollmen
            ts-Make-ups?language=en_US) for more information.
        name (str): The name of the class.
        service_id (int): The unique ID assigned to this pricing option when it was
            purchased by the client.
        service_name (str): The name of the pricing option at the site where it was
            purchased.
        service (ClientService): A service that is on a client's account.
        product_id (int): The ID of the pricing option at the site where it was
            purchased.
        signed_in (bool): When `true`, indicates that the client has been signed
            in.<br />  When `false`, indicates that the client has not been signed in.
        staff_id (int): The ID of the staff member who is teaching the class.
        web_signup (bool): When `true`, indicates that the client signed up
            online.<br />  When `false`, indicates that the client was signed up by a
            staff member.
        action (Action1Enum): The action taken.
        missed (bool): When `true`, indicates that the class has been `Missed`.<br />
            When `false`, indicates that the class has not been `Missed`.
        visit_type (int): Indicates the Id of visit type.
        type_group (int): Indicates the Id of type group.
        type_taken (str): Indicates the service type taken.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "appointment_id": "AppointmentId",
        "appointment_gender_preference": "AppointmentGenderPreference",
        "appointment_status": "AppointmentStatus",
        "class_id": "ClassId",
        "client_id": "ClientId",
        "client_photo_url": "ClientPhotoUrl",
        "client_unique_id": "ClientUniqueId",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "id": "Id",
        "last_modified_date_time": "LastModifiedDateTime",
        "late_cancelled": "LateCancelled",
        "site_id": "SiteId",
        "location_id": "LocationId",
        "make_up": "MakeUp",
        "name": "Name",
        "service_id": "ServiceId",
        "service_name": "ServiceName",
        "service": "Service",
        "product_id": "ProductId",
        "signed_in": "SignedIn",
        "staff_id": "StaffId",
        "web_signup": "WebSignup",
        "action": "Action",
        "missed": "Missed",
        "visit_type": "VisitType",
        "type_group": "TypeGroup",
        "type_taken": "TypeTaken",
    }

    _optionals = [
        "appointment_id",
        "appointment_gender_preference",
        "appointment_status",
        "class_id",
        "client_id",
        "client_photo_url",
        "client_unique_id",
        "start_date_time",
        "end_date_time",
        "id",
        "last_modified_date_time",
        "late_cancelled",
        "site_id",
        "location_id",
        "make_up",
        "name",
        "service_id",
        "service_name",
        "service",
        "product_id",
        "signed_in",
        "staff_id",
        "web_signup",
        "action",
        "missed",
        "visit_type",
        "type_group",
        "type_taken",
    ]

    def __init__(
        self,
        appointment_id=APIHelper.SKIP,
        appointment_gender_preference=APIHelper.SKIP,
        appointment_status=APIHelper.SKIP,
        class_id=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        client_photo_url=APIHelper.SKIP,
        client_unique_id=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        id=APIHelper.SKIP,
        last_modified_date_time=APIHelper.SKIP,
        late_cancelled=APIHelper.SKIP,
        site_id=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        make_up=APIHelper.SKIP,
        name=APIHelper.SKIP,
        service_id=APIHelper.SKIP,
        service_name=APIHelper.SKIP,
        service=APIHelper.SKIP,
        product_id=APIHelper.SKIP,
        signed_in=APIHelper.SKIP,
        staff_id=APIHelper.SKIP,
        web_signup=APIHelper.SKIP,
        action=APIHelper.SKIP,
        missed=APIHelper.SKIP,
        visit_type=APIHelper.SKIP,
        type_group=APIHelper.SKIP,
        type_taken=APIHelper.SKIP):
        """Initialize a Visit instance."""
        # Initialize members of the class
        if appointment_id is not APIHelper.SKIP:
            self.appointment_id = appointment_id
        if appointment_gender_preference is not APIHelper.SKIP:
            self.appointment_gender_preference = appointment_gender_preference
        if appointment_status is not APIHelper.SKIP:
            self.appointment_status = appointment_status
        if class_id is not APIHelper.SKIP:
            self.class_id = class_id
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if client_photo_url is not APIHelper.SKIP:
            self.client_photo_url = client_photo_url
        if client_unique_id is not APIHelper.SKIP:
            self.client_unique_id = client_unique_id
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if id is not APIHelper.SKIP:
            self.id = id
        if last_modified_date_time is not APIHelper.SKIP:
            self.last_modified_date_time =\
                 APIHelper.apply_datetime_converter(
                last_modified_date_time, APIHelper.RFC3339DateTime)\
                 if last_modified_date_time else None
        if late_cancelled is not APIHelper.SKIP:
            self.late_cancelled = late_cancelled
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if make_up is not APIHelper.SKIP:
            self.make_up = make_up
        if name is not APIHelper.SKIP:
            self.name = name
        if service_id is not APIHelper.SKIP:
            self.service_id = service_id
        if service_name is not APIHelper.SKIP:
            self.service_name = service_name
        if service is not APIHelper.SKIP:
            self.service = service
        if product_id is not APIHelper.SKIP:
            self.product_id = product_id
        if signed_in is not APIHelper.SKIP:
            self.signed_in = signed_in
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if web_signup is not APIHelper.SKIP:
            self.web_signup = web_signup
        if action is not APIHelper.SKIP:
            self.action = action
        if missed is not APIHelper.SKIP:
            self.missed = missed
        if visit_type is not APIHelper.SKIP:
            self.visit_type = visit_type
        if type_group is not APIHelper.SKIP:
            self.type_group = type_group
        if type_taken is not APIHelper.SKIP:
            self.type_taken = type_taken

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        appointment_id =\
            dictionary.get("AppointmentId")\
            if dictionary.get("AppointmentId")\
                else APIHelper.SKIP
        appointment_gender_preference =\
            dictionary.get("AppointmentGenderPreference")\
            if dictionary.get("AppointmentGenderPreference")\
                else APIHelper.SKIP
        appointment_status =\
            dictionary.get("AppointmentStatus")\
            if dictionary.get("AppointmentStatus")\
                else APIHelper.SKIP
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        client_photo_url =\
            dictionary.get("ClientPhotoUrl")\
            if dictionary.get("ClientPhotoUrl")\
                else APIHelper.SKIP
        client_unique_id =\
            dictionary.get("ClientUniqueId")\
            if dictionary.get("ClientUniqueId")\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        last_modified_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("LastModifiedDateTime")).datetime\
            if dictionary.get("LastModifiedDateTime") else APIHelper.SKIP
        late_cancelled =\
            dictionary.get("LateCancelled")\
            if "LateCancelled" in dictionary.keys()\
                else APIHelper.SKIP
        site_id =\
            dictionary.get("SiteId")\
            if dictionary.get("SiteId")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        make_up =\
            dictionary.get("MakeUp")\
            if "MakeUp" in dictionary.keys()\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        service_id =\
            dictionary.get("ServiceId")\
            if dictionary.get("ServiceId")\
                else APIHelper.SKIP
        service_name =\
            dictionary.get("ServiceName")\
            if dictionary.get("ServiceName")\
                else APIHelper.SKIP
        service =\
            ClientService.from_dictionary(
                dictionary.get("Service"))\
                if "Service" in dictionary.keys()\
                else APIHelper.SKIP
        product_id =\
            dictionary.get("ProductId")\
            if dictionary.get("ProductId")\
                else APIHelper.SKIP
        signed_in =\
            dictionary.get("SignedIn")\
            if "SignedIn" in dictionary.keys()\
                else APIHelper.SKIP
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        web_signup =\
            dictionary.get("WebSignup")\
            if "WebSignup" in dictionary.keys()\
                else APIHelper.SKIP
        action =\
            dictionary.get("Action")\
            if dictionary.get("Action")\
                else APIHelper.SKIP
        missed =\
            dictionary.get("Missed")\
            if "Missed" in dictionary.keys()\
                else APIHelper.SKIP
        visit_type =\
            dictionary.get("VisitType")\
            if dictionary.get("VisitType")\
                else APIHelper.SKIP
        type_group =\
            dictionary.get("TypeGroup")\
            if dictionary.get("TypeGroup")\
                else APIHelper.SKIP
        type_taken =\
            dictionary.get("TypeTaken")\
            if dictionary.get("TypeTaken")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(appointment_id,
                   appointment_gender_preference,
                   appointment_status,
                   class_id,
                   client_id,
                   client_photo_url,
                   client_unique_id,
                   start_date_time,
                   end_date_time,
                   id,
                   last_modified_date_time,
                   late_cancelled,
                   site_id,
                   location_id,
                   make_up,
                   name,
                   service_id,
                   service_name,
                   service,
                   product_id,
                   signed_in,
                   staff_id,
                   web_signup,
                   action,
                   missed,
                   visit_type,
                   type_group,
                   type_taken)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _appointment_gender_preference=(
            self.appointment_gender_preference
            if hasattr(self, "appointment_gender_preference")
            else None
        )
        _appointment_status=(
            self.appointment_status
            if hasattr(self, "appointment_status")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _client_photo_url=(
            self.client_photo_url
            if hasattr(self, "client_photo_url")
            else None
        )
        _client_unique_id=(
            self.client_unique_id
            if hasattr(self, "client_unique_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _last_modified_date_time=(
            self.last_modified_date_time
            if hasattr(self, "last_modified_date_time")
            else None
        )
        _late_cancelled=(
            self.late_cancelled
            if hasattr(self, "late_cancelled")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _make_up=(
            self.make_up
            if hasattr(self, "make_up")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _service_id=(
            self.service_id
            if hasattr(self, "service_id")
            else None
        )
        _service_name=(
            self.service_name
            if hasattr(self, "service_name")
            else None
        )
        _service=(
            self.service
            if hasattr(self, "service")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _signed_in=(
            self.signed_in
            if hasattr(self, "signed_in")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _web_signup=(
            self.web_signup
            if hasattr(self, "web_signup")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _missed=(
            self.missed
            if hasattr(self, "missed")
            else None
        )
        _visit_type=(
            self.visit_type
            if hasattr(self, "visit_type")
            else None
        )
        _type_group=(
            self.type_group
            if hasattr(self, "type_group")
            else None
        )
        _type_taken=(
            self.type_taken
            if hasattr(self, "type_taken")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"appointment_id={_appointment_id!r}, "
            f"appointment_gender_preference={_appointment_gender_preference!r}, "
            f"appointment_status={_appointment_status!r}, "
            f"class_id={_class_id!r}, "
            f"client_id={_client_id!r}, "
            f"client_photo_url={_client_photo_url!r}, "
            f"client_unique_id={_client_unique_id!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"id={_id!r}, "
            f"last_modified_date_time={_last_modified_date_time!r}, "
            f"late_cancelled={_late_cancelled!r}, "
            f"site_id={_site_id!r}, "
            f"location_id={_location_id!r}, "
            f"make_up={_make_up!r}, "
            f"name={_name!r}, "
            f"service_id={_service_id!r}, "
            f"service_name={_service_name!r}, "
            f"service={_service!r}, "
            f"product_id={_product_id!r}, "
            f"signed_in={_signed_in!r}, "
            f"staff_id={_staff_id!r}, "
            f"web_signup={_web_signup!r}, "
            f"action={_action!r}, "
            f"missed={_missed!r}, "
            f"visit_type={_visit_type!r}, "
            f"type_group={_type_group!r}, "
            f"type_taken={_type_taken!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _appointment_gender_preference=(
            self.appointment_gender_preference
            if hasattr(self, "appointment_gender_preference")
            else None
        )
        _appointment_status=(
            self.appointment_status
            if hasattr(self, "appointment_status")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _client_photo_url=(
            self.client_photo_url
            if hasattr(self, "client_photo_url")
            else None
        )
        _client_unique_id=(
            self.client_unique_id
            if hasattr(self, "client_unique_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _last_modified_date_time=(
            self.last_modified_date_time
            if hasattr(self, "last_modified_date_time")
            else None
        )
        _late_cancelled=(
            self.late_cancelled
            if hasattr(self, "late_cancelled")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _make_up=(
            self.make_up
            if hasattr(self, "make_up")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _service_id=(
            self.service_id
            if hasattr(self, "service_id")
            else None
        )
        _service_name=(
            self.service_name
            if hasattr(self, "service_name")
            else None
        )
        _service=(
            self.service
            if hasattr(self, "service")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _signed_in=(
            self.signed_in
            if hasattr(self, "signed_in")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _web_signup=(
            self.web_signup
            if hasattr(self, "web_signup")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _missed=(
            self.missed
            if hasattr(self, "missed")
            else None
        )
        _visit_type=(
            self.visit_type
            if hasattr(self, "visit_type")
            else None
        )
        _type_group=(
            self.type_group
            if hasattr(self, "type_group")
            else None
        )
        _type_taken=(
            self.type_taken
            if hasattr(self, "type_taken")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"appointment_id={_appointment_id!s}, "
            f"appointment_gender_preference={_appointment_gender_preference!s}, "
            f"appointment_status={_appointment_status!s}, "
            f"class_id={_class_id!s}, "
            f"client_id={_client_id!s}, "
            f"client_photo_url={_client_photo_url!s}, "
            f"client_unique_id={_client_unique_id!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"id={_id!s}, "
            f"last_modified_date_time={_last_modified_date_time!s}, "
            f"late_cancelled={_late_cancelled!s}, "
            f"site_id={_site_id!s}, "
            f"location_id={_location_id!s}, "
            f"make_up={_make_up!s}, "
            f"name={_name!s}, "
            f"service_id={_service_id!s}, "
            f"service_name={_service_name!s}, "
            f"service={_service!s}, "
            f"product_id={_product_id!s}, "
            f"signed_in={_signed_in!s}, "
            f"staff_id={_staff_id!s}, "
            f"web_signup={_web_signup!s}, "
            f"action={_action!s}, "
            f"missed={_missed!s}, "
            f"visit_type={_visit_type!s}, "
            f"type_group={_type_group!s}, "
            f"type_taken={_type_taken!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetScheduleItemsRequest(object):
    """Implementation of the 'GetScheduleItemsRequest' model.

    Attributes:
        location_ids (List[int]): A list of requested location IDs.
        staff_ids (List[int]): A list of requested staff IDs.
        start_date (datetime): The start date of the requested date range.   <br
            />Default: **today’s date**
        end_date (datetime): The end date of the requested date range.   <br
            />Default: **today’s date**
        ignore_prep_finish_times (bool): When `true`, appointment preparation and
            finish unavailabilities are not returned.   <br />Default: **false**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "location_ids": "LocationIds",
        "staff_ids": "StaffIds",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "ignore_prep_finish_times": "IgnorePrepFinishTimes",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "location_ids",
        "staff_ids",
        "start_date",
        "end_date",
        "ignore_prep_finish_times",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        location_ids=APIHelper.SKIP,
        staff_ids=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        ignore_prep_finish_times=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetScheduleItemsRequest instance."""
        # Initialize members of the class
        if location_ids is not APIHelper.SKIP:
            self.location_ids = location_ids
        if staff_ids is not APIHelper.SKIP:
            self.staff_ids = staff_ids
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if ignore_prep_finish_times is not APIHelper.SKIP:
            self.ignore_prep_finish_times = ignore_prep_finish_times
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        location_ids =\
            dictionary.get("LocationIds")\
            if dictionary.get("LocationIds")\
                else APIHelper.SKIP
        staff_ids =\
            dictionary.get("StaffIds")\
            if dictionary.get("StaffIds")\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        ignore_prep_finish_times =\
            dictionary.get("IgnorePrepFinishTimes")\
            if "IgnorePrepFinishTimes" in dictionary.keys()\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(location_ids,
                   staff_ids,
                   start_date,
                   end_date,
                   ignore_prep_finish_times,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _staff_ids=(
            self.staff_ids
            if hasattr(self, "staff_ids")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _ignore_prep_finish_times=(
            self.ignore_prep_finish_times
            if hasattr(self, "ignore_prep_finish_times")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"location_ids={_location_ids!r}, "
            f"staff_ids={_staff_ids!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f"ignore_prep_finish_times={_ignore_prep_finish_times!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _staff_ids=(
            self.staff_ids
            if hasattr(self, "staff_ids")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _ignore_prep_finish_times=(
            self.ignore_prep_finish_times
            if hasattr(self, "ignore_prep_finish_times")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"location_ids={_location_ids!s}, "
            f"staff_ids={_staff_ids!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f"ignore_prep_finish_times={_ignore_prep_finish_times!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetAvailableDatesResponse(object):
    """Implementation of the 'GetAvailableDatesResponse' model.

    Attributes:
        available_dates (List[datetime]): A list of dates where scheduled appointment
            availability was found after applying request filters.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "available_dates": "AvailableDates",
    }

    _optionals = [
        "available_dates",
    ]

    def __init__(
        self,
        available_dates=APIHelper.SKIP):
        """Initialize a GetAvailableDatesResponse instance."""
        # Initialize members of the class
        if available_dates is not None and available_dates is not APIHelper.SKIP:
            self.available_dates = APIHelper.apply_datetime_converter(
                available_dates, APIHelper.RFC3339DateTime)

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        available_dates = None
        if dictionary.get("AvailableDates") is not None:
            available_dates = list()
            for x in dictionary.get("AvailableDates"):
                available_dates.append(APIHelper.RFC3339DateTime.from_value(x).datetime)
        else:
            available_dates = APIHelper.SKIP

        # Return an object of this model
        return cls(available_dates)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _available_dates=(
            self.available_dates
            if hasattr(self, "available_dates")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"available_dates={_available_dates!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _available_dates=(
            self.available_dates
            if hasattr(self, "available_dates")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"available_dates={_available_dates!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class DeleteClientFormulaNoteRequest(object):
    """Implementation of the 'DeleteClientFormulaNoteRequest' model.

    Attributes:
        client_id (str): The client ID of the client whose formula note needs to be
            deleted.
        formula_note_id (int): The formula note ID for the note to be deleted.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "formula_note_id": "FormulaNoteId",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "limit",
        "offset",
    ]

    def __init__(
        self,
        client_id=None,
        formula_note_id=None,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a DeleteClientFormulaNoteRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        self.formula_note_id = formula_note_id
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        formula_note_id =\
            dictionary.get("FormulaNoteId")\
            if dictionary.get("FormulaNoteId")\
                else None
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   formula_note_id,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _formula_note_id=self.formula_note_id
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"formula_note_id={_formula_note_id!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _formula_note_id=self.formula_note_id
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"formula_note_id={_formula_note_id!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AppointmentOption(object):
    """Implementation of the 'AppointmentOption' model.

    An appointment option name/value pair

    Attributes:
        display_name (str): The name displayed for this appointment option.
        name (str): The name given to this option.
        value (str): The value of the option.
        mtype (str): The data type of the option value.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "display_name": "DisplayName",
        "name": "Name",
        "value": "Value",
        "mtype": "Type",
    }

    _optionals = [
        "display_name",
        "name",
        "value",
        "mtype",
    ]

    def __init__(
        self,
        display_name=APIHelper.SKIP,
        name=APIHelper.SKIP,
        value=APIHelper.SKIP,
        mtype=APIHelper.SKIP):
        """Initialize a AppointmentOption instance."""
        # Initialize members of the class
        if display_name is not APIHelper.SKIP:
            self.display_name = display_name
        if name is not APIHelper.SKIP:
            self.name = name
        if value is not APIHelper.SKIP:
            self.value = value
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        display_name =\
            dictionary.get("DisplayName")\
            if dictionary.get("DisplayName")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        value =\
            dictionary.get("Value")\
            if dictionary.get("Value")\
                else APIHelper.SKIP
        mtype =\
            dictionary.get("Type")\
            if dictionary.get("Type")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(display_name,
                   name,
                   value,
                   mtype)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _display_name=(
            self.display_name
            if hasattr(self, "display_name")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _value=(
            self.value
            if hasattr(self, "value")
            else None
        )
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"display_name={_display_name!r}, "
            f"name={_name!r}, "
            f"value={_value!r}, "
            f"mtype={_mtype!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _display_name=(
            self.display_name
            if hasattr(self, "display_name")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _value=(
            self.value
            if hasattr(self, "value")
            else None
        )
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"display_name={_display_name!s}, "
            f"name={_name!s}, "
            f"value={_value!s}, "
            f"mtype={_mtype!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class VisitWaitlistInfo(object):
    """Implementation of the 'VisitWaitlistInfo' model.

    A Visit DTO with Waitlist Informatoin

    Attributes:
        waitlist_id (int): waitlist entry Id
        waitlist_order_number (int): order of the waitlist entry

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "waitlist_id": "WaitlistId",
        "waitlist_order_number": "WaitlistOrderNumber",
    }

    _optionals = [
        "waitlist_id",
        "waitlist_order_number",
    ]

    def __init__(
        self,
        waitlist_id=APIHelper.SKIP,
        waitlist_order_number=APIHelper.SKIP):
        """Initialize a VisitWaitlistInfo instance."""
        # Initialize members of the class
        if waitlist_id is not APIHelper.SKIP:
            self.waitlist_id = waitlist_id
        if waitlist_order_number is not APIHelper.SKIP:
            self.waitlist_order_number = waitlist_order_number

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        waitlist_id =\
            dictionary.get("WaitlistId")\
            if dictionary.get("WaitlistId")\
                else APIHelper.SKIP
        waitlist_order_number =\
            dictionary.get("WaitlistOrderNumber")\
            if dictionary.get("WaitlistOrderNumber")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(waitlist_id,
                   waitlist_order_number)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _waitlist_id=(
            self.waitlist_id
            if hasattr(self, "waitlist_id")
            else None
        )
        _waitlist_order_number=(
            self.waitlist_order_number
            if hasattr(self, "waitlist_order_number")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"waitlist_id={_waitlist_id!r}, "
            f"waitlist_order_number={_waitlist_order_number!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _waitlist_id=(
            self.waitlist_id
            if hasattr(self, "waitlist_id")
            else None
        )
        _waitlist_order_number=(
            self.waitlist_order_number
            if hasattr(self, "waitlist_order_number")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"waitlist_id={_waitlist_id!s}, "
            f"waitlist_order_number={_waitlist_order_number!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class Spot(object):
    """Implementation of the 'Spot' model.

    Contains information about the spot details.

    Attributes:
        reserved_spot_numbers (List[int]): Contains information about the collection
            of reserved spot numbers.
        available_spot_numbers (List[int]): Contains information about the collection
            of available spot numbers.
        unavailable_spot_numbers (List[int]): Contains information about the
            collection of Unavailable spot numbers.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "reserved_spot_numbers": "ReservedSpotNumbers",
        "available_spot_numbers": "AvailableSpotNumbers",
        "unavailable_spot_numbers": "UnavailableSpotNumbers",
    }

    _optionals = [
        "reserved_spot_numbers",
        "available_spot_numbers",
        "unavailable_spot_numbers",
    ]

    def __init__(
        self,
        reserved_spot_numbers=APIHelper.SKIP,
        available_spot_numbers=APIHelper.SKIP,
        unavailable_spot_numbers=APIHelper.SKIP):
        """Initialize a Spot instance."""
        # Initialize members of the class
        if reserved_spot_numbers is not APIHelper.SKIP:
            self.reserved_spot_numbers = reserved_spot_numbers
        if available_spot_numbers is not APIHelper.SKIP:
            self.available_spot_numbers = available_spot_numbers
        if unavailable_spot_numbers is not APIHelper.SKIP:
            self.unavailable_spot_numbers = unavailable_spot_numbers

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        reserved_spot_numbers =\
            dictionary.get("ReservedSpotNumbers")\
            if dictionary.get("ReservedSpotNumbers")\
                else APIHelper.SKIP
        available_spot_numbers =\
            dictionary.get("AvailableSpotNumbers")\
            if dictionary.get("AvailableSpotNumbers")\
                else APIHelper.SKIP
        unavailable_spot_numbers =\
            dictionary.get("UnavailableSpotNumbers")\
            if dictionary.get("UnavailableSpotNumbers")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(reserved_spot_numbers,
                   available_spot_numbers,
                   unavailable_spot_numbers)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _reserved_spot_numbers=(
            self.reserved_spot_numbers
            if hasattr(self, "reserved_spot_numbers")
            else None
        )
        _available_spot_numbers=(
            self.available_spot_numbers
            if hasattr(self, "available_spot_numbers")
            else None
        )
        _unavailable_spot_numbers=(
            self.unavailable_spot_numbers
            if hasattr(self, "unavailable_spot_numbers")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"reserved_spot_numbers={_reserved_spot_numbers!r}, "
            f"available_spot_numbers={_available_spot_numbers!r}, "
            f"unavailable_spot_numbers={_unavailable_spot_numbers!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _reserved_spot_numbers=(
            self.reserved_spot_numbers
            if hasattr(self, "reserved_spot_numbers")
            else None
        )
        _available_spot_numbers=(
            self.available_spot_numbers
            if hasattr(self, "available_spot_numbers")
            else None
        )
        _unavailable_spot_numbers=(
            self.unavailable_spot_numbers
            if hasattr(self, "unavailable_spot_numbers")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"reserved_spot_numbers={_reserved_spot_numbers!s}, "
            f"available_spot_numbers={_available_spot_numbers!s}, "
            f"unavailable_spot_numbers={_unavailable_spot_numbers!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetProductsInventoryRequest(object):
    """Implementation of the 'GetProductsInventoryRequest' model.

    Attributes:
        product_ids (List[str]): When included, the response only contains details
            about the specified product Ids.
        location_ids (List[int]): When included, the response only contains details
            about the specified location Ids.
        barcode_ids (List[str]): When included, the response only contains details
            about the specified Barcode Ids.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "product_ids": "ProductIds",
        "location_ids": "LocationIds",
        "barcode_ids": "BarcodeIds",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "product_ids",
        "location_ids",
        "barcode_ids",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        product_ids=APIHelper.SKIP,
        location_ids=APIHelper.SKIP,
        barcode_ids=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetProductsInventoryRequest instance."""
        # Initialize members of the class
        if product_ids is not APIHelper.SKIP:
            self.product_ids = product_ids
        if location_ids is not APIHelper.SKIP:
            self.location_ids = location_ids
        if barcode_ids is not APIHelper.SKIP:
            self.barcode_ids = barcode_ids
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        product_ids =\
            dictionary.get("ProductIds")\
            if dictionary.get("ProductIds")\
                else APIHelper.SKIP
        location_ids =\
            dictionary.get("LocationIds")\
            if dictionary.get("LocationIds")\
                else APIHelper.SKIP
        barcode_ids =\
            dictionary.get("BarcodeIds")\
            if dictionary.get("BarcodeIds")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(product_ids,
                   location_ids,
                   barcode_ids,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _product_ids=(
            self.product_ids
            if hasattr(self, "product_ids")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _barcode_ids=(
            self.barcode_ids
            if hasattr(self, "barcode_ids")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"product_ids={_product_ids!r}, "
            f"location_ids={_location_ids!r}, "
            f"barcode_ids={_barcode_ids!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _product_ids=(
            self.product_ids
            if hasattr(self, "product_ids")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _barcode_ids=(
            self.barcode_ids
            if hasattr(self, "barcode_ids")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"product_ids={_product_ids!s}, "
            f"location_ids={_location_ids!s}, "
            f"barcode_ids={_barcode_ids!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.cart_item import (
    CartItem,
)
from mindbodypublicapi.models.transaction_response import (
    TransactionResponse,
)


class ShoppingCart(object):
    """Implementation of the 'ShoppingCart' model.

    Represents a shopping cart.

    Attributes:
        id (str): The shopping cart ID.
        cart_items (List[CartItem]): Contains information about the items in the
            shopping cart.
        sub_total (float): The cart’s total cost before taxes and discounts were
            applied.
        discount_total (float): The monetary amount removed from the cart’s total
            cost by applied discounts.
        tax_total (float): The monetary amount paid in taxes, included in the cart’s
            `GrandTotal`.
        grand_total (float): The cart’s total cost, including taxes and discounts.
        transactions (List[TransactionResponse]): Contains information returned from
            the first call to CheckoutShoppingCart.
        sale_id (int): The ID of the sale associated with the shopping cart.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "cart_items": "CartItems",
        "sub_total": "SubTotal",
        "discount_total": "DiscountTotal",
        "tax_total": "TaxTotal",
        "grand_total": "GrandTotal",
        "transactions": "Transactions",
        "sale_id": "SaleId",
    }

    _optionals = [
        "id",
        "cart_items",
        "sub_total",
        "discount_total",
        "tax_total",
        "grand_total",
        "transactions",
        "sale_id",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        cart_items=APIHelper.SKIP,
        sub_total=APIHelper.SKIP,
        discount_total=APIHelper.SKIP,
        tax_total=APIHelper.SKIP,
        grand_total=APIHelper.SKIP,
        transactions=APIHelper.SKIP,
        sale_id=APIHelper.SKIP):
        """Initialize a ShoppingCart instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if cart_items is not APIHelper.SKIP:
            self.cart_items = cart_items
        if sub_total is not APIHelper.SKIP:
            self.sub_total = sub_total
        if discount_total is not APIHelper.SKIP:
            self.discount_total = discount_total
        if tax_total is not APIHelper.SKIP:
            self.tax_total = tax_total
        if grand_total is not APIHelper.SKIP:
            self.grand_total = grand_total
        if transactions is not APIHelper.SKIP:
            self.transactions = transactions
        if sale_id is not APIHelper.SKIP:
            self.sale_id = sale_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        cart_items = None
        if dictionary.get("CartItems") is not None:
            cart_items = [
                CartItem.from_dictionary(x)
                    for x in dictionary.get("CartItems")
            ]
        else:
            cart_items = APIHelper.SKIP
        sub_total =\
            dictionary.get("SubTotal")\
            if dictionary.get("SubTotal")\
                else APIHelper.SKIP
        discount_total =\
            dictionary.get("DiscountTotal")\
            if dictionary.get("DiscountTotal")\
                else APIHelper.SKIP
        tax_total =\
            dictionary.get("TaxTotal")\
            if dictionary.get("TaxTotal")\
                else APIHelper.SKIP
        grand_total =\
            dictionary.get("GrandTotal")\
            if dictionary.get("GrandTotal")\
                else APIHelper.SKIP
        transactions = None
        if dictionary.get("Transactions") is not None:
            transactions = [
                TransactionResponse.from_dictionary(x)
                    for x in dictionary.get("Transactions")
            ]
        else:
            transactions = APIHelper.SKIP
        sale_id =\
            dictionary.get("SaleId")\
            if dictionary.get("SaleId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   cart_items,
                   sub_total,
                   discount_total,
                   tax_total,
                   grand_total,
                   transactions,
                   sale_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _cart_items=(
            self.cart_items
            if hasattr(self, "cart_items")
            else None
        )
        _sub_total=(
            self.sub_total
            if hasattr(self, "sub_total")
            else None
        )
        _discount_total=(
            self.discount_total
            if hasattr(self, "discount_total")
            else None
        )
        _tax_total=(
            self.tax_total
            if hasattr(self, "tax_total")
            else None
        )
        _grand_total=(
            self.grand_total
            if hasattr(self, "grand_total")
            else None
        )
        _transactions=(
            self.transactions
            if hasattr(self, "transactions")
            else None
        )
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"cart_items={_cart_items!r}, "
            f"sub_total={_sub_total!r}, "
            f"discount_total={_discount_total!r}, "
            f"tax_total={_tax_total!r}, "
            f"grand_total={_grand_total!r}, "
            f"transactions={_transactions!r}, "
            f"sale_id={_sale_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _cart_items=(
            self.cart_items
            if hasattr(self, "cart_items")
            else None
        )
        _sub_total=(
            self.sub_total
            if hasattr(self, "sub_total")
            else None
        )
        _discount_total=(
            self.discount_total
            if hasattr(self, "discount_total")
            else None
        )
        _tax_total=(
            self.tax_total
            if hasattr(self, "tax_total")
            else None
        )
        _grand_total=(
            self.grand_total
            if hasattr(self, "grand_total")
            else None
        )
        _transactions=(
            self.transactions
            if hasattr(self, "transactions")
            else None
        )
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"cart_items={_cart_items!s}, "
            f"sub_total={_sub_total!s}, "
            f"discount_total={_discount_total!s}, "
            f"tax_total={_tax_total!s}, "
            f"grand_total={_grand_total!s}, "
            f"transactions={_transactions!s}, "
            f"sale_id={_sale_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.client import (
    Client,
)
from mindbodypublicapi.models.contact_log_comment import (
    ContactLogComment,
)
from mindbodypublicapi.models.contact_log_type import (
    ContactLogType,
)
from mindbodypublicapi.models.staff import Staff


class ContactLog(object):
    """Implementation of the 'ContactLog' model.

    A contact log.

    Attributes:
        id (int): The contact log’s ID.
        text (str): The contact log’s body text.
        created_date_time (datetime): The local date and time when the contact log
            was created.
        followup_by_date (datetime): The date by which the assigned staff member
            should close or follow up on this contact log.
        contact_method (str): The method by which the client wants to be contacted.
        contact_name (str): The name of the client to contact.
        client (Client): The Client.
        created_by (Staff): The Staff
        assigned_to (Staff): The Staff
        comments (List[ContactLogComment]): Information about the comment.
        types (List[ContactLogType]): Information about the type of contact log.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "text": "Text",
        "created_date_time": "CreatedDateTime",
        "followup_by_date": "FollowupByDate",
        "contact_method": "ContactMethod",
        "contact_name": "ContactName",
        "client": "Client",
        "created_by": "CreatedBy",
        "assigned_to": "AssignedTo",
        "comments": "Comments",
        "types": "Types",
    }

    _optionals = [
        "id",
        "text",
        "created_date_time",
        "followup_by_date",
        "contact_method",
        "contact_name",
        "client",
        "created_by",
        "assigned_to",
        "comments",
        "types",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        text=APIHelper.SKIP,
        created_date_time=APIHelper.SKIP,
        followup_by_date=APIHelper.SKIP,
        contact_method=APIHelper.SKIP,
        contact_name=APIHelper.SKIP,
        client=APIHelper.SKIP,
        created_by=APIHelper.SKIP,
        assigned_to=APIHelper.SKIP,
        comments=APIHelper.SKIP,
        types=APIHelper.SKIP):
        """Initialize a ContactLog instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if text is not APIHelper.SKIP:
            self.text = text
        if created_date_time is not APIHelper.SKIP:
            self.created_date_time =\
                 APIHelper.apply_datetime_converter(
                created_date_time, APIHelper.RFC3339DateTime)\
                 if created_date_time else None
        if followup_by_date is not APIHelper.SKIP:
            self.followup_by_date =\
                 APIHelper.apply_datetime_converter(
                followup_by_date, APIHelper.RFC3339DateTime)\
                 if followup_by_date else None
        if contact_method is not APIHelper.SKIP:
            self.contact_method = contact_method
        if contact_name is not APIHelper.SKIP:
            self.contact_name = contact_name
        if client is not APIHelper.SKIP:
            self.client = client
        if created_by is not APIHelper.SKIP:
            self.created_by = created_by
        if assigned_to is not APIHelper.SKIP:
            self.assigned_to = assigned_to
        if comments is not APIHelper.SKIP:
            self.comments = comments
        if types is not APIHelper.SKIP:
            self.types = types

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        text =\
            dictionary.get("Text")\
            if dictionary.get("Text")\
                else APIHelper.SKIP
        created_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("CreatedDateTime")).datetime\
            if dictionary.get("CreatedDateTime") else APIHelper.SKIP
        followup_by_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("FollowupByDate")).datetime\
            if dictionary.get("FollowupByDate") else APIHelper.SKIP
        contact_method =\
            dictionary.get("ContactMethod")\
            if dictionary.get("ContactMethod")\
                else APIHelper.SKIP
        contact_name =\
            dictionary.get("ContactName")\
            if dictionary.get("ContactName")\
                else APIHelper.SKIP
        client =\
            Client.from_dictionary(
                dictionary.get("Client"))\
                if "Client" in dictionary.keys()\
                else APIHelper.SKIP
        created_by =\
            Staff.from_dictionary(
                dictionary.get("CreatedBy"))\
                if "CreatedBy" in dictionary.keys()\
                else APIHelper.SKIP
        assigned_to =\
            Staff.from_dictionary(
                dictionary.get("AssignedTo"))\
                if "AssignedTo" in dictionary.keys()\
                else APIHelper.SKIP
        comments = None
        if dictionary.get("Comments") is not None:
            comments = [
                ContactLogComment.from_dictionary(x)
                    for x in dictionary.get("Comments")
            ]
        else:
            comments = APIHelper.SKIP
        types = None
        if dictionary.get("Types") is not None:
            types = [
                ContactLogType.from_dictionary(x)
                    for x in dictionary.get("Types")
            ]
        else:
            types = APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   text,
                   created_date_time,
                   followup_by_date,
                   contact_method,
                   contact_name,
                   client,
                   created_by,
                   assigned_to,
                   comments,
                   types)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _text=(
            self.text
            if hasattr(self, "text")
            else None
        )
        _created_date_time=(
            self.created_date_time
            if hasattr(self, "created_date_time")
            else None
        )
        _followup_by_date=(
            self.followup_by_date
            if hasattr(self, "followup_by_date")
            else None
        )
        _contact_method=(
            self.contact_method
            if hasattr(self, "contact_method")
            else None
        )
        _contact_name=(
            self.contact_name
            if hasattr(self, "contact_name")
            else None
        )
        _client=(
            self.client
            if hasattr(self, "client")
            else None
        )
        _created_by=(
            self.created_by
            if hasattr(self, "created_by")
            else None
        )
        _assigned_to=(
            self.assigned_to
            if hasattr(self, "assigned_to")
            else None
        )
        _comments=(
            self.comments
            if hasattr(self, "comments")
            else None
        )
        _types=(
            self.types
            if hasattr(self, "types")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"text={_text!r}, "
            f"created_date_time={_created_date_time!r}, "
            f"followup_by_date={_followup_by_date!r}, "
            f"contact_method={_contact_method!r}, "
            f"contact_name={_contact_name!r}, "
            f"client={_client!r}, "
            f"created_by={_created_by!r}, "
            f"assigned_to={_assigned_to!r}, "
            f"comments={_comments!r}, "
            f"types={_types!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _text=(
            self.text
            if hasattr(self, "text")
            else None
        )
        _created_date_time=(
            self.created_date_time
            if hasattr(self, "created_date_time")
            else None
        )
        _followup_by_date=(
            self.followup_by_date
            if hasattr(self, "followup_by_date")
            else None
        )
        _contact_method=(
            self.contact_method
            if hasattr(self, "contact_method")
            else None
        )
        _contact_name=(
            self.contact_name
            if hasattr(self, "contact_name")
            else None
        )
        _client=(
            self.client
            if hasattr(self, "client")
            else None
        )
        _created_by=(
            self.created_by
            if hasattr(self, "created_by")
            else None
        )
        _assigned_to=(
            self.assigned_to
            if hasattr(self, "assigned_to")
            else None
        )
        _comments=(
            self.comments
            if hasattr(self, "comments")
            else None
        )
        _types=(
            self.types
            if hasattr(self, "types")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"text={_text!s}, "
            f"created_date_time={_created_date_time!s}, "
            f"followup_by_date={_followup_by_date!s}, "
            f"contact_method={_contact_method!s}, "
            f"contact_name={_contact_name!s}, "
            f"client={_client!s}, "
            f"created_by={_created_by!s}, "
            f"assigned_to={_assigned_to!s}, "
            f"comments={_comments!s}, "
            f"types={_types!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class Relationship(object):
    """Implementation of the 'Relationship' model.

    Jim is a RelationshipName1 of John. John is a RelationshipName2 of Jim.

    Attributes:
        id (int): The ID of the relationship.
        relationship_name_1 (str): The name of the first relationship.
        relationship_name_2 (str): The name of the second relationship.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "relationship_name_1": "RelationshipName1",
        "relationship_name_2": "RelationshipName2",
    }

    _optionals = [
        "id",
        "relationship_name_1",
        "relationship_name_2",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        relationship_name_1=APIHelper.SKIP,
        relationship_name_2=APIHelper.SKIP):
        """Initialize a Relationship instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if relationship_name_1 is not APIHelper.SKIP:
            self.relationship_name_1 = relationship_name_1
        if relationship_name_2 is not APIHelper.SKIP:
            self.relationship_name_2 = relationship_name_2

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        relationship_name_1 =\
            dictionary.get("RelationshipName1")\
            if dictionary.get("RelationshipName1")\
                else APIHelper.SKIP
        relationship_name_2 =\
            dictionary.get("RelationshipName2")\
            if dictionary.get("RelationshipName2")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   relationship_name_1,
                   relationship_name_2)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _relationship_name_1=(
            self.relationship_name_1
            if hasattr(self, "relationship_name_1")
            else None
        )
        _relationship_name_2=(
            self.relationship_name_2
            if hasattr(self, "relationship_name_2")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"relationship_name_1={_relationship_name_1!r}, "
            f"relationship_name_2={_relationship_name_2!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _relationship_name_1=(
            self.relationship_name_1
            if hasattr(self, "relationship_name_1")
            else None
        )
        _relationship_name_2=(
            self.relationship_name_2
            if hasattr(self, "relationship_name_2")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"relationship_name_1={_relationship_name_1!s}, "
            f"relationship_name_2={_relationship_name_2!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetActivationCodeResponse(object):
    """Implementation of the 'GetActivationCodeResponse' model.

    Attributes:
        activation_code (str): An activation code used to provide access to a site’s
            business data through MINDBODY.
        activation_link (str): A link to the Manage Credentials screen.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "activation_code": "ActivationCode",
        "activation_link": "ActivationLink",
    }

    _optionals = [
        "activation_code",
        "activation_link",
    ]

    def __init__(
        self,
        activation_code=APIHelper.SKIP,
        activation_link=APIHelper.SKIP):
        """Initialize a GetActivationCodeResponse instance."""
        # Initialize members of the class
        if activation_code is not APIHelper.SKIP:
            self.activation_code = activation_code
        if activation_link is not APIHelper.SKIP:
            self.activation_link = activation_link

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        activation_code =\
            dictionary.get("ActivationCode")\
            if dictionary.get("ActivationCode")\
                else APIHelper.SKIP
        activation_link =\
            dictionary.get("ActivationLink")\
            if dictionary.get("ActivationLink")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(activation_code,
                   activation_link)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _activation_code=(
            self.activation_code
            if hasattr(self, "activation_code")
            else None
        )
        _activation_link=(
            self.activation_link
            if hasattr(self, "activation_link")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"activation_code={_activation_code!r}, "
            f"activation_link={_activation_link!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _activation_code=(
            self.activation_code
            if hasattr(self, "activation_code")
            else None
        )
        _activation_link=(
            self.activation_link
            if hasattr(self, "activation_link")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"activation_code={_activation_code!s}, "
            f"activation_link={_activation_link!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.payment_processing_failure import (
    PaymentProcessingFailure,
)
from mindbodypublicapi.models.purchase_contract_response_totals import (
    PurchaseContractResponseTotals,
)


class PurchaseContractResponse(object):
    """Implementation of the 'PurchaseContractResponse' model.

    Response model for POST PurchaseContract endpoint

    Attributes:
        client_id (str): The ID of the client who is purchasing the contract.
        unique_client_id (int): The Unique ID of the client who is purchasing the
            contract.
        location_id (int): The ID of the location where the contract is being
            purchased.
        contract_id (int): The ID of the general contract being purchased.
        client_contract_id (int): The ID of the specific contract being purchased by
            this specific client, not to be confused with the `ContractId`, which
            refers to a general contract that the business offers.
        totals (PurchaseContractResponseTotals): Totals for the purchase
        payment_processing_failures (List[PaymentProcessingFailure]): Contains
            information only if SCA challenge is indicated.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "unique_client_id": "UniqueClientId",
        "location_id": "LocationId",
        "contract_id": "ContractId",
        "client_contract_id": "ClientContractId",
        "totals": "Totals",
        "payment_processing_failures": "PaymentProcessingFailures",
    }

    _optionals = [
        "client_id",
        "unique_client_id",
        "location_id",
        "contract_id",
        "client_contract_id",
        "totals",
        "payment_processing_failures",
    ]

    def __init__(
        self,
        client_id=APIHelper.SKIP,
        unique_client_id=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        contract_id=APIHelper.SKIP,
        client_contract_id=APIHelper.SKIP,
        totals=APIHelper.SKIP,
        payment_processing_failures=APIHelper.SKIP):
        """Initialize a PurchaseContractResponse instance."""
        # Initialize members of the class
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if unique_client_id is not APIHelper.SKIP:
            self.unique_client_id = unique_client_id
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if contract_id is not APIHelper.SKIP:
            self.contract_id = contract_id
        if client_contract_id is not APIHelper.SKIP:
            self.client_contract_id = client_contract_id
        if totals is not APIHelper.SKIP:
            self.totals = totals
        if payment_processing_failures is not APIHelper.SKIP:
            self.payment_processing_failures = payment_processing_failures

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        unique_client_id =\
            dictionary.get("UniqueClientId")\
            if dictionary.get("UniqueClientId")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        contract_id =\
            dictionary.get("ContractId")\
            if dictionary.get("ContractId")\
                else APIHelper.SKIP
        client_contract_id =\
            dictionary.get("ClientContractId")\
            if dictionary.get("ClientContractId")\
                else APIHelper.SKIP
        totals =\
            PurchaseContractResponseTotals.from_dictionary(
                dictionary.get("Totals"))\
                if "Totals" in dictionary.keys()\
                else APIHelper.SKIP
        payment_processing_failures = None
        if dictionary.get("PaymentProcessingFailures") is not None:
            payment_processing_failures = [
                PaymentProcessingFailure.from_dictionary(x)
                    for x in dictionary.get("PaymentProcessingFailures")
            ]
        else:
            payment_processing_failures = APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   unique_client_id,
                   location_id,
                   contract_id,
                   client_contract_id,
                   totals,
                   payment_processing_failures)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _contract_id=(
            self.contract_id
            if hasattr(self, "contract_id")
            else None
        )
        _client_contract_id=(
            self.client_contract_id
            if hasattr(self, "client_contract_id")
            else None
        )
        _totals=(
            self.totals
            if hasattr(self, "totals")
            else None
        )
        _payment_processing_failures=(
            self.payment_processing_failures
            if hasattr(self, "payment_processing_failures")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"unique_client_id={_unique_client_id!r}, "
            f"location_id={_location_id!r}, "
            f"contract_id={_contract_id!r}, "
            f"client_contract_id={_client_contract_id!r}, "
            f"totals={_totals!r}, "
            f"payment_processing_failures={_payment_processing_failures!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _contract_id=(
            self.contract_id
            if hasattr(self, "contract_id")
            else None
        )
        _client_contract_id=(
            self.client_contract_id
            if hasattr(self, "client_contract_id")
            else None
        )
        _totals=(
            self.totals
            if hasattr(self, "totals")
            else None
        )
        _payment_processing_failures=(
            self.payment_processing_failures
            if hasattr(self, "payment_processing_failures")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"unique_client_id={_unique_client_id!s}, "
            f"location_id={_location_id!s}, "
            f"contract_id={_contract_id!s}, "
            f"client_contract_id={_client_contract_id!s}, "
            f"totals={_totals!s}, "
            f"payment_processing_failures={_payment_processing_failures!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class Discount(object):
    """Implementation of the 'Discount' model.

    Discount for a promo code

    Attributes:
        mtype (str): Type of discount percentage/amount
        amount (float): Amount of discount

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype": "Type",
        "amount": "Amount",
    }

    _optionals = [
        "mtype",
        "amount",
    ]

    def __init__(
        self,
        mtype=APIHelper.SKIP,
        amount=APIHelper.SKIP):
        """Initialize a Discount instance."""
        # Initialize members of the class
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype
        if amount is not APIHelper.SKIP:
            self.amount = amount

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype =\
            dictionary.get("Type")\
            if dictionary.get("Type")\
                else APIHelper.SKIP
        amount =\
            dictionary.get("Amount")\
            if dictionary.get("Amount")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(mtype,
                   amount)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _amount=(
            self.amount
            if hasattr(self, "amount")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"mtype={_mtype!r}, "
            f"amount={_amount!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _amount=(
            self.amount
            if hasattr(self, "amount")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"mtype={_mtype!s}, "
            f"amount={_amount!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class Semester(object):
    """Implementation of the 'Semester' model.

    Semesters help you quickly classify enrollments.

    Attributes:
        id (int): This semester’s unique ID.
        name (str): Name of the semester.
        description (str): The description of the semester.
        start_date (datetime): Start date of the semester.
        end_date (datetime): End date of the semester.
        multi_registration_discount (float): Discount for multiple registration in
            the semester.
        multi_registration_deadline (datetime): Registration deadline of the semester.
        active (bool): When `true`, indicates that the semester is active.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "name": "Name",
        "description": "Description",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "multi_registration_discount": "MultiRegistrationDiscount",
        "multi_registration_deadline": "MultiRegistrationDeadline",
        "active": "Active",
    }

    _optionals = [
        "id",
        "name",
        "description",
        "start_date",
        "end_date",
        "multi_registration_discount",
        "multi_registration_deadline",
        "active",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        description=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        multi_registration_discount=APIHelper.SKIP,
        multi_registration_deadline=APIHelper.SKIP,
        active=APIHelper.SKIP):
        """Initialize a Semester instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if description is not APIHelper.SKIP:
            self.description = description
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if multi_registration_discount is not APIHelper.SKIP:
            self.multi_registration_discount = multi_registration_discount
        if multi_registration_deadline is not APIHelper.SKIP:
            self.multi_registration_deadline =\
                 APIHelper.apply_datetime_converter(
                multi_registration_deadline, APIHelper.RFC3339DateTime)\
                 if multi_registration_deadline else None
        if active is not APIHelper.SKIP:
            self.active = active

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        multi_registration_discount =\
            dictionary.get("MultiRegistrationDiscount")\
            if dictionary.get("MultiRegistrationDiscount")\
                else APIHelper.SKIP
        multi_registration_deadline = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("MultiRegistrationDeadline")).datetime\
            if dictionary.get("MultiRegistrationDeadline") else APIHelper.SKIP
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   name,
                   description,
                   start_date,
                   end_date,
                   multi_registration_discount,
                   multi_registration_deadline,
                   active)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _multi_registration_discount=(
            self.multi_registration_discount
            if hasattr(self, "multi_registration_discount")
            else None
        )
        _multi_registration_deadline=(
            self.multi_registration_deadline
            if hasattr(self, "multi_registration_deadline")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"description={_description!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f"multi_registration_discount={_multi_registration_discount!r}, "
            f"multi_registration_deadline={_multi_registration_deadline!r}, "
            f"active={_active!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _multi_registration_discount=(
            self.multi_registration_discount
            if hasattr(self, "multi_registration_discount")
            else None
        )
        _multi_registration_deadline=(
            self.multi_registration_deadline
            if hasattr(self, "multi_registration_deadline")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"description={_description!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f"multi_registration_discount={_multi_registration_discount!s}, "
            f"multi_registration_deadline={_multi_registration_deadline!s}, "
            f"active={_active!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class Transaction(object):
    """Implementation of the 'Transaction' model.

    Attributes:
        transaction_id (int): The transaction ID.
        sale_id (int): The sale ID.
        client_id (int): The ID of the client who made the purchase.
        amount (float): The amount charged on the card
        settled (bool): Whether it is settled or not
        status (str): Status of the transaction
        transaction_time (datetime): Time of card swiped
        auth_time (datetime): Time of card authorized
        location_id (int): The ID of the location where the sale takes place.
        merchant_id (str): Merchant ID of the studio
        terminal_id (str): Terminal ID used for payment. Not applicable for CNP/Bank
        card_expiration_month (str): Expiry month of the card
        card_expiration_year (str): Expiry year of the card
        cc_last_four (str): Last 4 digits of CC
        card_type (str): Type of the card
        cc_swiped (bool): Whether card is swiped or not
        ach_last_four (str): Customer’s ACH last 4 digits

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "transaction_id": "TransactionId",
        "sale_id": "SaleId",
        "client_id": "ClientId",
        "amount": "Amount",
        "settled": "Settled",
        "status": "Status",
        "transaction_time": "TransactionTime",
        "auth_time": "AuthTime",
        "location_id": "LocationId",
        "merchant_id": "MerchantId",
        "terminal_id": "TerminalId",
        "card_expiration_month": "CardExpirationMonth",
        "card_expiration_year": "CardExpirationYear",
        "cc_last_four": "CCLastFour",
        "card_type": "CardType",
        "cc_swiped": "CCSwiped",
        "ach_last_four": "ACHLastFour",
    }

    _optionals = [
        "transaction_id",
        "sale_id",
        "client_id",
        "amount",
        "settled",
        "status",
        "transaction_time",
        "auth_time",
        "location_id",
        "merchant_id",
        "terminal_id",
        "card_expiration_month",
        "card_expiration_year",
        "cc_last_four",
        "card_type",
        "cc_swiped",
        "ach_last_four",
    ]

    def __init__(
        self,
        transaction_id=APIHelper.SKIP,
        sale_id=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        amount=APIHelper.SKIP,
        settled=APIHelper.SKIP,
        status=APIHelper.SKIP,
        transaction_time=APIHelper.SKIP,
        auth_time=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        merchant_id=APIHelper.SKIP,
        terminal_id=APIHelper.SKIP,
        card_expiration_month=APIHelper.SKIP,
        card_expiration_year=APIHelper.SKIP,
        cc_last_four=APIHelper.SKIP,
        card_type=APIHelper.SKIP,
        cc_swiped=APIHelper.SKIP,
        ach_last_four=APIHelper.SKIP):
        """Initialize a Transaction instance."""
        # Initialize members of the class
        if transaction_id is not APIHelper.SKIP:
            self.transaction_id = transaction_id
        if sale_id is not APIHelper.SKIP:
            self.sale_id = sale_id
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if amount is not APIHelper.SKIP:
            self.amount = amount
        if settled is not APIHelper.SKIP:
            self.settled = settled
        if status is not APIHelper.SKIP:
            self.status = status
        if transaction_time is not APIHelper.SKIP:
            self.transaction_time =\
                 APIHelper.apply_datetime_converter(
                transaction_time, APIHelper.RFC3339DateTime)\
                 if transaction_time else None
        if auth_time is not APIHelper.SKIP:
            self.auth_time =\
                 APIHelper.apply_datetime_converter(
                auth_time, APIHelper.RFC3339DateTime)\
                 if auth_time else None
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if merchant_id is not APIHelper.SKIP:
            self.merchant_id = merchant_id
        if terminal_id is not APIHelper.SKIP:
            self.terminal_id = terminal_id
        if card_expiration_month is not APIHelper.SKIP:
            self.card_expiration_month = card_expiration_month
        if card_expiration_year is not APIHelper.SKIP:
            self.card_expiration_year = card_expiration_year
        if cc_last_four is not APIHelper.SKIP:
            self.cc_last_four = cc_last_four
        if card_type is not APIHelper.SKIP:
            self.card_type = card_type
        if cc_swiped is not APIHelper.SKIP:
            self.cc_swiped = cc_swiped
        if ach_last_four is not APIHelper.SKIP:
            self.ach_last_four = ach_last_four

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        transaction_id =\
            dictionary.get("TransactionId")\
            if dictionary.get("TransactionId")\
                else APIHelper.SKIP
        sale_id =\
            dictionary.get("SaleId")\
            if dictionary.get("SaleId")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        amount =\
            dictionary.get("Amount")\
            if dictionary.get("Amount")\
                else APIHelper.SKIP
        settled =\
            dictionary.get("Settled")\
            if "Settled" in dictionary.keys()\
                else APIHelper.SKIP
        status =\
            dictionary.get("Status")\
            if dictionary.get("Status")\
                else APIHelper.SKIP
        transaction_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("TransactionTime")).datetime\
            if dictionary.get("TransactionTime") else APIHelper.SKIP
        auth_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("AuthTime")).datetime\
            if dictionary.get("AuthTime") else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        merchant_id =\
            dictionary.get("MerchantId")\
            if dictionary.get("MerchantId")\
                else APIHelper.SKIP
        terminal_id =\
            dictionary.get("TerminalId")\
            if dictionary.get("TerminalId")\
                else APIHelper.SKIP
        card_expiration_month =\
            dictionary.get("CardExpirationMonth")\
            if dictionary.get("CardExpirationMonth")\
                else APIHelper.SKIP
        card_expiration_year =\
            dictionary.get("CardExpirationYear")\
            if dictionary.get("CardExpirationYear")\
                else APIHelper.SKIP
        cc_last_four =\
            dictionary.get("CCLastFour")\
            if dictionary.get("CCLastFour")\
                else APIHelper.SKIP
        card_type =\
            dictionary.get("CardType")\
            if dictionary.get("CardType")\
                else APIHelper.SKIP
        cc_swiped =\
            dictionary.get("CCSwiped")\
            if "CCSwiped" in dictionary.keys()\
                else APIHelper.SKIP
        ach_last_four =\
            dictionary.get("ACHLastFour")\
            if dictionary.get("ACHLastFour")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(transaction_id,
                   sale_id,
                   client_id,
                   amount,
                   settled,
                   status,
                   transaction_time,
                   auth_time,
                   location_id,
                   merchant_id,
                   terminal_id,
                   card_expiration_month,
                   card_expiration_year,
                   cc_last_four,
                   card_type,
                   cc_swiped,
                   ach_last_four)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _transaction_id=(
            self.transaction_id
            if hasattr(self, "transaction_id")
            else None
        )
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _amount=(
            self.amount
            if hasattr(self, "amount")
            else None
        )
        _settled=(
            self.settled
            if hasattr(self, "settled")
            else None
        )
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        _transaction_time=(
            self.transaction_time
            if hasattr(self, "transaction_time")
            else None
        )
        _auth_time=(
            self.auth_time
            if hasattr(self, "auth_time")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _merchant_id=(
            self.merchant_id
            if hasattr(self, "merchant_id")
            else None
        )
        _terminal_id=(
            self.terminal_id
            if hasattr(self, "terminal_id")
            else None
        )
        _card_expiration_month=(
            self.card_expiration_month
            if hasattr(self, "card_expiration_month")
            else None
        )
        _card_expiration_year=(
            self.card_expiration_year
            if hasattr(self, "card_expiration_year")
            else None
        )
        _cc_last_four=(
            self.cc_last_four
            if hasattr(self, "cc_last_four")
            else None
        )
        _card_type=(
            self.card_type
            if hasattr(self, "card_type")
            else None
        )
        _cc_swiped=(
            self.cc_swiped
            if hasattr(self, "cc_swiped")
            else None
        )
        _ach_last_four=(
            self.ach_last_four
            if hasattr(self, "ach_last_four")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"transaction_id={_transaction_id!r}, "
            f"sale_id={_sale_id!r}, "
            f"client_id={_client_id!r}, "
            f"amount={_amount!r}, "
            f"settled={_settled!r}, "
            f"status={_status!r}, "
            f"transaction_time={_transaction_time!r}, "
            f"auth_time={_auth_time!r}, "
            f"location_id={_location_id!r}, "
            f"merchant_id={_merchant_id!r}, "
            f"terminal_id={_terminal_id!r}, "
            f"card_expiration_month={_card_expiration_month!r}, "
            f"card_expiration_year={_card_expiration_year!r}, "
            f"cc_last_four={_cc_last_four!r}, "
            f"card_type={_card_type!r}, "
            f"cc_swiped={_cc_swiped!r}, "
            f"ach_last_four={_ach_last_four!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _transaction_id=(
            self.transaction_id
            if hasattr(self, "transaction_id")
            else None
        )
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _amount=(
            self.amount
            if hasattr(self, "amount")
            else None
        )
        _settled=(
            self.settled
            if hasattr(self, "settled")
            else None
        )
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        _transaction_time=(
            self.transaction_time
            if hasattr(self, "transaction_time")
            else None
        )
        _auth_time=(
            self.auth_time
            if hasattr(self, "auth_time")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _merchant_id=(
            self.merchant_id
            if hasattr(self, "merchant_id")
            else None
        )
        _terminal_id=(
            self.terminal_id
            if hasattr(self, "terminal_id")
            else None
        )
        _card_expiration_month=(
            self.card_expiration_month
            if hasattr(self, "card_expiration_month")
            else None
        )
        _card_expiration_year=(
            self.card_expiration_year
            if hasattr(self, "card_expiration_year")
            else None
        )
        _cc_last_four=(
            self.cc_last_four
            if hasattr(self, "cc_last_four")
            else None
        )
        _card_type=(
            self.card_type
            if hasattr(self, "card_type")
            else None
        )
        _cc_swiped=(
            self.cc_swiped
            if hasattr(self, "cc_swiped")
            else None
        )
        _ach_last_four=(
            self.ach_last_four
            if hasattr(self, "ach_last_four")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"transaction_id={_transaction_id!s}, "
            f"sale_id={_sale_id!s}, "
            f"client_id={_client_id!s}, "
            f"amount={_amount!s}, "
            f"settled={_settled!s}, "
            f"status={_status!s}, "
            f"transaction_time={_transaction_time!s}, "
            f"auth_time={_auth_time!s}, "
            f"location_id={_location_id!s}, "
            f"merchant_id={_merchant_id!s}, "
            f"terminal_id={_terminal_id!s}, "
            f"card_expiration_month={_card_expiration_month!s}, "
            f"card_expiration_year={_card_expiration_year!s}, "
            f"cc_last_four={_cc_last_four!s}, "
            f"card_type={_card_type!s}, "
            f"cc_swiped={_cc_swiped!s}, "
            f"ach_last_four={_ach_last_four!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UnavailabilityPlain(object):
    """Implementation of the 'UnavailabilityPlain' model.

    Attributes:
        id (int): The ID of the unavailability.
        staff_id (int): Id of the staff
        start_date_time (datetime): The date and time the unavailability starts.
        end_date_time (datetime): The date and time the unavailability ends.
        description (str): A description of the unavailability.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "staff_id": "StaffId",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "description": "Description",
    }

    _optionals = [
        "id",
        "staff_id",
        "start_date_time",
        "end_date_time",
        "description",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        staff_id=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        description=APIHelper.SKIP):
        """Initialize a UnavailabilityPlain instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if description is not APIHelper.SKIP:
            self.description = description

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   staff_id,
                   start_date_time,
                   end_date_time,
                   description)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"staff_id={_staff_id!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"description={_description!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"staff_id={_staff_id!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"description={_description!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetGiftCardsRequest(object):
    """Implementation of the 'GetGiftCardsRequest' model.

    Attributes:
        location_id (int): When included, returns gift cards that are sold at the
            provided location ID.
        sold_online (bool): When `true`, only returns gift cards that are sold
            online.<br />  Default: **false**
        include_custom_layouts (bool): When `true`, includes custom gift card
            layouts.<br />  When `false`, includes only system layouts.  Default:
            **false**
        ids (List[int]): Filters the results to the requested gift card IDs.<br />
            Default: **all** gift cards.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "location_id": "LocationId",
        "sold_online": "SoldOnline",
        "include_custom_layouts": "IncludeCustomLayouts",
        "ids": "Ids",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "location_id",
        "sold_online",
        "include_custom_layouts",
        "ids",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        location_id=APIHelper.SKIP,
        sold_online=APIHelper.SKIP,
        include_custom_layouts=APIHelper.SKIP,
        ids=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetGiftCardsRequest instance."""
        # Initialize members of the class
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if sold_online is not APIHelper.SKIP:
            self.sold_online = sold_online
        if include_custom_layouts is not APIHelper.SKIP:
            self.include_custom_layouts = include_custom_layouts
        if ids is not APIHelper.SKIP:
            self.ids = ids
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        sold_online =\
            dictionary.get("SoldOnline")\
            if "SoldOnline" in dictionary.keys()\
                else APIHelper.SKIP
        include_custom_layouts =\
            dictionary.get("IncludeCustomLayouts")\
            if "IncludeCustomLayouts" in dictionary.keys()\
                else APIHelper.SKIP
        ids =\
            dictionary.get("Ids")\
            if dictionary.get("Ids")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(location_id,
                   sold_online,
                   include_custom_layouts,
                   ids,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _sold_online=(
            self.sold_online
            if hasattr(self, "sold_online")
            else None
        )
        _include_custom_layouts=(
            self.include_custom_layouts
            if hasattr(self, "include_custom_layouts")
            else None
        )
        _ids=(
            self.ids
            if hasattr(self, "ids")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"location_id={_location_id!r}, "
            f"sold_online={_sold_online!r}, "
            f"include_custom_layouts={_include_custom_layouts!r}, "
            f"ids={_ids!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _sold_online=(
            self.sold_online
            if hasattr(self, "sold_online")
            else None
        )
        _include_custom_layouts=(
            self.include_custom_layouts
            if hasattr(self, "include_custom_layouts")
            else None
        )
        _ids=(
            self.ids
            if hasattr(self, "ids")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"location_id={_location_id!s}, "
            f"sold_online={_sold_online!s}, "
            f"include_custom_layouts={_include_custom_layouts!s}, "
            f"ids={_ids!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ReturnSaleResponse(object):
    """Implementation of the 'ReturnSaleResponse' model.

    ReturnSaleResponse

    Attributes:
        return_sale_id (int): The returned sale ID
        trainer_id (int): The trainer ID who returned the sale
        amount (float): The returned amount

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "return_sale_id": "ReturnSaleID",
        "trainer_id": "TrainerID",
        "amount": "Amount",
    }

    _optionals = [
        "return_sale_id",
        "trainer_id",
        "amount",
    ]

    def __init__(
        self,
        return_sale_id=APIHelper.SKIP,
        trainer_id=APIHelper.SKIP,
        amount=APIHelper.SKIP):
        """Initialize a ReturnSaleResponse instance."""
        # Initialize members of the class
        if return_sale_id is not APIHelper.SKIP:
            self.return_sale_id = return_sale_id
        if trainer_id is not APIHelper.SKIP:
            self.trainer_id = trainer_id
        if amount is not APIHelper.SKIP:
            self.amount = amount

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        return_sale_id =\
            dictionary.get("ReturnSaleID")\
            if dictionary.get("ReturnSaleID")\
                else APIHelper.SKIP
        trainer_id =\
            dictionary.get("TrainerID")\
            if dictionary.get("TrainerID")\
                else APIHelper.SKIP
        amount =\
            dictionary.get("Amount")\
            if dictionary.get("Amount")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(return_sale_id,
                   trainer_id,
                   amount)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _return_sale_id=(
            self.return_sale_id
            if hasattr(self, "return_sale_id")
            else None
        )
        _trainer_id=(
            self.trainer_id
            if hasattr(self, "trainer_id")
            else None
        )
        _amount=(
            self.amount
            if hasattr(self, "amount")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"return_sale_id={_return_sale_id!r}, "
            f"trainer_id={_trainer_id!r}, "
            f"amount={_amount!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _return_sale_id=(
            self.return_sale_id
            if hasattr(self, "return_sale_id")
            else None
        )
        _trainer_id=(
            self.trainer_id
            if hasattr(self, "trainer_id")
            else None
        )
        _amount=(
            self.amount
            if hasattr(self, "amount")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"return_sale_id={_return_sale_id!s}, "
            f"trainer_id={_trainer_id!s}, "
            f"amount={_amount!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.api_error import (
    ApiError,
)
from mindbodypublicapi.models.staff import Staff


class UpdateAvailabilityResponse(object):
    """Implementation of the 'UpdateAvailabilityResponse' model.

    This is the update avaialability response

    Attributes:
        staff_members (List[Staff]): This is the success list of the trainer
            availability
        errors (List[ApiError]): The model property of type List[ApiError].

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_members": "StaffMembers",
        "errors": "Errors",
    }

    _optionals = [
        "staff_members",
        "errors",
    ]

    def __init__(
        self,
        staff_members=APIHelper.SKIP,
        errors=APIHelper.SKIP):
        """Initialize a UpdateAvailabilityResponse instance."""
        # Initialize members of the class
        if staff_members is not APIHelper.SKIP:
            self.staff_members = staff_members
        if errors is not APIHelper.SKIP:
            self.errors = errors

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_members = None
        if dictionary.get("StaffMembers") is not None:
            staff_members = [
                Staff.from_dictionary(x)
                    for x in dictionary.get("StaffMembers")
            ]
        else:
            staff_members = APIHelper.SKIP
        errors = None
        if dictionary.get("Errors") is not None:
            errors = [
                ApiError.from_dictionary(x)
                    for x in dictionary.get("Errors")
            ]
        else:
            errors = APIHelper.SKIP

        # Return an object of this model
        return cls(staff_members,
                   errors)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_members=(
            self.staff_members
            if hasattr(self, "staff_members")
            else None
        )
        _errors=(
            self.errors
            if hasattr(self, "errors")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_members={_staff_members!r}, "
            f"errors={_errors!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_members=(
            self.staff_members
            if hasattr(self, "staff_members")
            else None
        )
        _errors=(
            self.errors
            if hasattr(self, "errors")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_members={_staff_members!s}, "
            f"errors={_errors!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetMembershipsRequest(object):
    """Implementation of the 'GetMembershipsRequest' model.

    Attributes:
        membership_ids (List[int]): The requested membership IDs.<br />  Default:
            **all** IDs that the authenticated user’s access level allows.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "membership_ids": "MembershipIds",
    }

    _optionals = [
        "membership_ids",
    ]

    def __init__(
        self,
        membership_ids=APIHelper.SKIP):
        """Initialize a GetMembershipsRequest instance."""
        # Initialize members of the class
        if membership_ids is not APIHelper.SKIP:
            self.membership_ids = membership_ids

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        membership_ids =\
            dictionary.get("MembershipIds")\
            if dictionary.get("MembershipIds")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(membership_ids)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _membership_ids=(
            self.membership_ids
            if hasattr(self, "membership_ids")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"membership_ids={_membership_ids!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _membership_ids=(
            self.membership_ids
            if hasattr(self, "membership_ids")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"membership_ids={_membership_ids!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetClientReferralTypesRequest(object):
    """Implementation of the 'GetClientReferralTypesRequest' model.

    Attributes:
        include_inactive (bool): When `true`, filters the results to include subtypes
            and inactive referral types.<br />  When `false`, includes no subtypes
            and only active types.  Default:**false**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "include_inactive": "IncludeInactive",
    }

    _optionals = [
        "include_inactive",
    ]

    def __init__(
        self,
        include_inactive=APIHelper.SKIP):
        """Initialize a GetClientReferralTypesRequest instance."""
        # Initialize members of the class
        if include_inactive is not APIHelper.SKIP:
            self.include_inactive = include_inactive

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        include_inactive =\
            dictionary.get("IncludeInactive")\
            if "IncludeInactive" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(include_inactive)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _include_inactive=(
            self.include_inactive
            if hasattr(self, "include_inactive")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"include_inactive={_include_inactive!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _include_inactive=(
            self.include_inactive
            if hasattr(self, "include_inactive")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"include_inactive={_include_inactive!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetActiveClientMembershipsRequest(object):
    """Implementation of the 'GetActiveClientMembershipsRequest' model.

    Attributes:
        client_id (str): The ID of the client for whom memberships are returned.
        unique_client_id (int): The Unique ID of the client for whom memberships are
            returned. Note that UniqueClientId takes precedence over ClientId if both
            are provided.
        location_id (int): Filters results to memberships that can be used to pay for
            scheduled services at that location. This parameter can not be passed
            when `CrossRegionalLookup` is `true`.
        cross_regional_lookup (bool): Used to retrieve a client’s memberships from
            multiple sites within an organization. When included and set to `true`,
            it searches a maximum of ten sites with which this client is associated.
            When a client is associated with more than ten sites, use
            `ClientAssociatedSitesOffset` as many times as needed to search the
            additional sites with which the client is associated. You can use the
            `CrossRegionalClientAssociations` value from `GET
            CrossRegionalClientAssociations` to determine how many sites the client
            is associated with. Note that a `SiteID` is returned and populated in the
            `ClientServices` response when `CrossRegionalLookup` is set to `true`.
            Default: **false**
        client_associated_sites_offset (int): Used to retrieve a client’s memberships
            from multiple sites within an organization when the client is associated
            with more than ten sites. To change which ten sites are searched, change
            this offset value. A value of 0 means that no sites are skipped and the
            first ten sites are returned. You can use the
            `CrossRegionalClientAssociations` value from `GET
            CrossRegionalClientAssociations` to determine how many sites the client
            is associated with. Note that you must always have `CrossRegionalLookup`
            set to `true` to use this parameter.<br />  Default: **0**    For
            example, if a client is associated with 25 sites, you need to call GET
            `ActiveClientMemberships` three times, as follows:  * Use GET
            `CrossRegionalClientAssociations` to determine how many sites a client is
            associated with, which tells you how many additional calls you need to
            make.  * Either omit `ClientAssociatedSitesOffset` or set it to 0 to
            return the client’s memberships from sites 1-10  * Set
            `ClientAssociatedSitesOffset` to 10 to return the client’s memberships
            from sites 11-20  * Set `ClientAssociatedSitesOffset` to 20 to return the
            client’s memberships from sites 21-25
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "unique_client_id": "UniqueClientId",
        "location_id": "LocationId",
        "cross_regional_lookup": "CrossRegionalLookup",
        "client_associated_sites_offset": "ClientAssociatedSitesOffset",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "unique_client_id",
        "location_id",
        "cross_regional_lookup",
        "client_associated_sites_offset",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        client_id=None,
        unique_client_id=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        cross_regional_lookup=APIHelper.SKIP,
        client_associated_sites_offset=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetActiveClientMembershipsRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        if unique_client_id is not APIHelper.SKIP:
            self.unique_client_id = unique_client_id
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if cross_regional_lookup is not APIHelper.SKIP:
            self.cross_regional_lookup = cross_regional_lookup
        if client_associated_sites_offset is not APIHelper.SKIP:
            self.client_associated_sites_offset = client_associated_sites_offset
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        unique_client_id =\
            dictionary.get("UniqueClientId")\
            if dictionary.get("UniqueClientId")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        cross_regional_lookup =\
            dictionary.get("CrossRegionalLookup")\
            if "CrossRegionalLookup" in dictionary.keys()\
                else APIHelper.SKIP
        client_associated_sites_offset =\
            dictionary.get("ClientAssociatedSitesOffset")\
            if dictionary.get("ClientAssociatedSitesOffset")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   unique_client_id,
                   location_id,
                   cross_regional_lookup,
                   client_associated_sites_offset,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _cross_regional_lookup=(
            self.cross_regional_lookup
            if hasattr(self, "cross_regional_lookup")
            else None
        )
        _client_associated_sites_offset=(
            self.client_associated_sites_offset
            if hasattr(self, "client_associated_sites_offset")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"unique_client_id={_unique_client_id!r}, "
            f"location_id={_location_id!r}, "
            f"cross_regional_lookup={_cross_regional_lookup!r}, "
            f"client_associated_sites_offset={_client_associated_sites_offset!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _cross_regional_lookup=(
            self.cross_regional_lookup
            if hasattr(self, "cross_regional_lookup")
            else None
        )
        _client_associated_sites_offset=(
            self.client_associated_sites_offset
            if hasattr(self, "client_associated_sites_offset")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"unique_client_id={_unique_client_id!s}, "
            f"location_id={_location_id!s}, "
            f"cross_regional_lookup={_cross_regional_lookup!s}, "
            f"client_associated_sites_offset={_client_associated_sites_offset!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )
